@@ -1,5 +1,5 @@
-import classstuff
-from classstuff import *
+import  extra_Encodings_pkg.classstuff
+from  extra_Encodings_pkg.classstuff import *
 countingstuff = 0
 #Gen2
 Encodeable_letters = r'''aAbBcCdDeEfFgGhHiIjJkKlLmMnNoOpPqQrRsStTuUvVwWxXyYzZ1234567890!@\#$%^&*()`~-=_+[]}{'\";:| ,.<>/?'''
@@ -90,8 +90,6 @@ for letter in Encodeable_letters:
     Gen2.append(letter)
     LTF64.append(letter)
     GTX2.append(letter)
-print(ichor)
-print(ichor.rev_dict)
 def Gen2Code(Character_to_decode):
     ''' Only use with r-strings due to % and \. Don't mind strange coloration as that is just your text   editor rendering it incorrectly'''
     #make sure this is always a string
@@ -100,7 +98,6 @@ def Gen2Code(Character_to_decode):
         charpos = Gen2.index(character)
         ResultStr = str(Gen2[-charpos])
         print(ResultStr,end='')
-
 def LTF64Code(Character_to_decode):
     '''Only use with r-strings due to % and \. Don't mind strange coloration as that is just your text editor rendering it incorrectly'''
     #make sure this is always a string
@@ -119,4 +116,23 @@ def GTX2Code(Character_to_decode):
         print(ResultStr,end='')
 #Example \/ Make sure to reset the file once you are finshed or make a copy of this file
 #LTF64Code(r'Fire balls')
+#!!!!!----------!!!!!!
+#Beyond this line are items that are not available 
+#in the pre made encoder and are only to help you make your own encoders
+# and stuff
+#!!!!!!!--------------!!!!!
+Madeencodings = 0
+class Encoding():
+    '''A way to generate a encoding for your purposes. \n
+    Look at CreateAnEncoding.py to see an example of making an instance
+    '''
+    def __init__(self,rate):
+        self.rate = rate
+        x = 0
+        self.encodingnormal = {}
+        for letter in Encodeable_letters:
+            x = x + rate
+            self.encodingnormal[letter] = x
+        self.encoding = TwoWayDict(self.encodingnormal)
+            
 
